@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from typing import Any, cast
+from typing import Any
 
 from anthropic.types.beta import BetaToolParam, BetaToolUnionParam
 from anthropic.types.beta.beta_tool_param import InputSchema
@@ -7,6 +7,7 @@ from PIL import Image
 from pydantic import BaseModel, Field
 from typing_extensions import Self
 
+from askui.logger import logger
 from askui.models.shared.agent_message_param import (
     Base64ImageSourceParam,
     ContentBlockParam,
@@ -147,10 +148,7 @@ class ToolCollection:
                 tool_use_id=tool_use_block_param.id,
             )
         try:
-            tool_result: ToolCallResult = cast(
-                "ToolCallResult",
-                tool(**tool_use_block_param.input),  # type: ignore
-            )
+            tool_result: ToolCallResult = tool(**tool_use_block_param.input)  # type: ignore
             return ToolResultBlockParam(
                 content=_convert_to_content(tool_result),
                 tool_use_id=tool_use_block_param.id,
@@ -158,6 +156,7 @@ class ToolCollection:
         except AgentException:
             raise
         except Exception as e:  # noqa: BLE001
+            logger.error(f"Tool {tool_use_block_param.name} failed: {e}", exc_info=True)
             return ToolResultBlockParam(
                 content=f"Tool {tool_use_block_param.name} failed: {e}",
                 is_error=True,
